@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2018 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -61,10 +61,9 @@ free_regions (struct regions *rs)
  * to find the end of the region.
  */
 static int
-compare_offset (const void *offsetp, const void *regionp)
+compare_offset (const void *offsetp, const struct region *region)
 {
   const uint64_t offset = *(uint64_t *)offsetp;
-  const struct region *region = (struct region *)regionp;
 
   if (offset < region->start) return -1;
   if (offset > region->end) return 1;
@@ -74,8 +73,7 @@ compare_offset (const void *offsetp, const void *regionp)
 const struct region *
 find_region (const regions *rs, uint64_t offset)
 {
-  return bsearch (&offset, rs->ptr, rs->size,
-                  sizeof (struct region), compare_offset);
+  return regions_search (rs, &offset, compare_offset);
 }
 
 /* This is the low level function for constructing the list of
@@ -84,7 +82,7 @@ find_region (const regions *rs, uint64_t offset)
  * and contiguous) is maintained.  Note it is not possible to
  * construct regions out of order using this function.
  */
-static int __attribute__((__nonnull__ (1)))
+static int __attribute__ ((__nonnull__ (1)))
 append_one_region (regions *rs, struct region region)
 {
   /* The assertions in this function are meant to maintain the
@@ -121,10 +119,10 @@ append_padding (regions *rs, uint64_t alignment)
 }
 
 int
-append_region_len (regions *rs,
+append_region_va (regions *rs,
                    const char *description, uint64_t len,
                    uint64_t pre_aligment, uint64_t post_alignment,
-                   enum region_type type, ...)
+                   enum region_type type, va_list ap)
 {
   struct region region;
 
@@ -141,24 +139,10 @@ append_region_len (regions *rs,
   region.len = len;
   region.end = region.start + region.len - 1;
   region.type = type;
-  if (type == region_file) {
-    va_list ap;
-    size_t i;
-
-    va_start (ap, type);
-    i = va_arg (ap, size_t);
-    va_end (ap);
-    region.u.i = i;
-  }
-  else if (type == region_data) {
-    va_list ap;
-    const unsigned char *data;
-
-    va_start (ap, type);
-    data = va_arg (ap, const unsigned char *);
-    va_end (ap);
-    region.u.data = data;
-  }
+  if (type == region_file)
+    region.u.i = va_arg (ap, size_t);
+  else if (type == region_data)
+    region.u.data = va_arg (ap, const unsigned char *);
   if (append_one_region (rs, region) == -1)
     return -1;
 
@@ -171,3 +155,37 @@ append_region_len (regions *rs,
 
   return 0;
 }
+
+int
+append_region_len (regions *rs,
+                   const char *description, uint64_t len,
+                   uint64_t pre_aligment, uint64_t post_alignment,
+                   enum region_type type, ...)
+{
+  va_list ap;
+  int r;
+
+  va_start (ap, type);
+  r = append_region_va (rs, description, len,
+                        pre_aligment, post_alignment, type, ap);
+  va_end (ap);
+  return r;
+}
+
+int
+append_region_end (regions *rs,
+                   const char *description, uint64_t end,
+                   uint64_t pre_aligment, uint64_t post_alignment,
+                   enum region_type type, ...)
+{
+  va_list ap;
+  int r;
+  uint64_t len;
+
+  va_start (ap, type);
+  len = end - virtual_size (rs) + 1;
+  r = append_region_va (rs, description, len,
+                        pre_aligment, post_alignment, type, ap);
+  va_end (ap);
+  return r;
+}
