@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2018-2022 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -98,8 +98,9 @@ nozero_config (nbdkit_next_config *next, nbdkit_backend *nxdata,
   return next (nxdata, key, value);
 }
 
-#define nozero_config_help \
-  "zeromode=<MODE>      One of 'none' (default), 'emulate', 'notrim', 'plugin'.\n" \
+#define nozero_config_help                                               \
+  "zeromode=<MODE>      One of 'none' (default), 'emulate', 'notrim',\n" \
+  "                     'plugin'.\n"                                     \
   "fastzeromode=<MODE>  One of 'default', 'none', 'slow', 'ignore'.\n"
 
 /* Check that desired mode is supported by plugin. */
@@ -185,4 +186,4 @@ static struct nbdkit_filter filter = {
   .zero              = nozero_zero,
 };
 
-NBDKIT_REGISTER_FILTER(filter)
+NBDKIT_REGISTER_FILTER (filter)
