@@ -35,10 +35,14 @@
 
 #include <nbdkit-filter.h>
 
-#define SECTOR_SIZE 512
+#define SECTOR_SIZE_4K      4096
+#define SECTOR_SIZE_512     512
+#define SECTOR_SIZE_DEFAULT SECTOR_SIZE_512
 
 extern unsigned partnum;
 
+extern unsigned sector_size;
+
 extern int find_mbr_partition (nbdkit_next *next,
                                int64_t size, uint8_t *mbr,
                                int64_t *offset_r, int64_t *range_r);
