@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2017-2018 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -94,6 +94,23 @@ full_get_size (void *handle)
   return size;
 }
 
+/* Serves the same data over multiple connections. */
+static int
+full_can_multi_conn (void *handle)
+{
+  return 1;
+}
+
+/* Cache. */
+static int
+full_can_cache (void *handle)
+{
+  /* Everything is already in memory, returning this without
+   * implementing .cache lets nbdkit do the correct no-op.
+   */
+  return NBDKIT_CACHE_NATIVE;
+}
+
 /* Read data. */
 static int
 full_pread (void *handle, void *buf, uint32_t count, uint64_t offset,
@@ -112,13 +129,10 @@ full_pwrite (void *handle, const void *buf, uint32_t count, uint64_t offset,
   return -1;
 }
 
-/* Write zeroes. */
-static int
-full_zero (void *handle, uint32_t count, uint64_t offset, uint32_t flags)
-{
-  errno = ENOSPC;
-  return -1;
-}
+/* Omitting full_zero is intentional: that way, nbdkit defaults to
+ * permitting fast zeroes which respond with ENOTSUP, while normal
+ * zeroes fall back to pwrite and respond with ENOSPC.
+ */
 
 /* Trim. */
 static int
@@ -148,11 +162,13 @@ static struct nbdkit_plugin plugin = {
   .config            = full_config,
   .config_complete   = full_config_complete,
   .config_help       = full_config_help,
+  .magic_config_key  = "size",
   .open              = full_open,
   .get_size          = full_get_size,
+  .can_multi_conn    = full_can_multi_conn,
+  .can_cache         = full_can_cache,
   .pread             = full_pread,
   .pwrite            = full_pwrite,
-  .zero              = full_zero,
   .trim              = full_trim,
   .extents           = full_extents,
   /* In this plugin, errno is preserved properly along error return
@@ -161,4 +177,4 @@ static struct nbdkit_plugin plugin = {
   .errno_is_preserved = 1,
 };
 
-NBDKIT_REGISTER_PLUGIN(plugin)
+NBDKIT_REGISTER_PLUGIN (plugin)
