@@ -453,6 +453,9 @@ do_extents (struct command *cmd, struct vddk_handle *h)
 
       blk_offset = block_list->blocks[i].offset * VIXDISKLIB_SECTOR_SIZE;
       blk_length = block_list->blocks[i].length * VIXDISKLIB_SECTOR_SIZE;
+      nbdkit_debug ("QueryAllocatedBlocks returned allocated block at "
+                    "%" PRIu64 "-%" PRIu64 " (length %" PRIu64 ")",
+                    blk_offset, blk_offset + blk_length-1, blk_length);
 
       /* The query returns allocated blocks.  We must insert holes
        * between the blocks as necessary.
