@@ -42,6 +42,20 @@
 #include <sys/socket.h>
 #endif
 
+/* Do we have the --timeout option?
+ *
+ * OpenBSD defines timer_create as a function that returns -ENOSYS,
+ * which breaks configure.  So we have to check for SIGEV_THREAD being
+ * defined as well.
+ * https://github.com/openbsd/src/blob/master/lib/libc/sys/timer_create.c
+ */
+#include <signal.h>
+#include <time.h>
+
+#if defined(HAVE_TIMER_CREATE) && defined(SIGEV_THREAD)
+#define HAVE_TIMEOUT_OPTION 1
+#endif
+
 /* Server supports API versions between 1 and MAX_API_VERSION */
 #define MAX_API_VERSION 2
 
@@ -127,6 +141,7 @@ extern struct debug_flag *debug_flags;
 extern const char *export_name;
 extern bool foreground;
 extern const char *ipaddr;
+extern bool keepalive;
 extern enum log_to log_to;
 extern unsigned mask_handshake;
 extern bool newstyle;
@@ -139,6 +154,7 @@ extern const char *run;
 extern bool listen_stdin;
 extern const char *selinux_label;
 extern unsigned threads;
+extern unsigned timeout_secs, timeout_nsecs;
 extern int tls;
 extern const char *tls_certificates_dir;
 extern const char *tls_psk;
@@ -192,6 +208,13 @@ extern void run_command (void);
 #define FIRST_SOCKET_ACTIVATION_FD 3 /* defined by systemd ABI */
 extern unsigned int get_socket_activation (void);
 
+/* timeout.c */
+struct connection;
+extern int start_timeout (struct connection *conn)
+  __attribute__ ((__nonnull__ (1)));
+extern void cancel_timeout (struct connection *conn)
+  __attribute__ ((__nonnull__ (1)));
+
 /* usergroup.c */
 extern void change_user (void);
 
@@ -281,6 +304,10 @@ struct connection {
   uint32_t cflags;
   uint16_t eflags;
   bool handshake_complete;
+#ifdef HAVE_TIMEOUT_OPTION
+  timer_t timer;
+  bool timer_set;
+#endif
   bool using_tls;
   bool structured_replies;
   bool meta_context_base_allocation;
