@@ -48,6 +48,7 @@
 #include <errno.h>
 #include <signal.h>
 #include <sys/types.h>
+#include <math.h>
 
 #ifdef HAVE_TERMIOS_H
 #include <termios.h>
@@ -75,6 +76,7 @@
 #include "ascii-string.h"
 #include "get_current_dir_name.h"
 #include "getline.h"
+#include "human-size.h"
 #include "poll.h"
 #include "realpath.h"
 #include "strndup.h"
@@ -342,83 +344,58 @@ nbdkit_parse_uint64_t (const char *what, const char *str, uint64_t *rp)
 NBDKIT_DLL_PUBLIC int64_t
 nbdkit_parse_size (const char *str)
 {
+  const char *error = NULL, *pstr = NULL;
   int64_t size;
-  char *end;
-  uint64_t scale = 1;
 
-  /* Disk sizes cannot usefully exceed off_t (which is signed) and
-   * cannot be negative.  */
-  /* XXX Should we also parse things like '1.5M'? */
-  /* XXX Should we allow hex? If so, hex cannot use scaling suffixes,
-   * because some of them are valid hex digits */
-  errno = 0;
-  size = strtoimax (str, &end, 10);
-  if (str == end) {
-    nbdkit_error ("could not parse size string (%s)", str);
-    return -1;
-  }
-  if (size < 0) {
-    nbdkit_error ("size cannot be negative (%s)", str);
-    return -1;
-  }
-  if (errno) {
-    nbdkit_error ("size (%s) exceeds maximum value", str);
+  size = human_size_parse (str, &error, &pstr);
+  if (size == -1) {
+    nbdkit_error ("%s: %s", error, pstr);
     return -1;
   }
 
-  switch (*end) {
-    /* No suffix */
-  case '\0':
-    end--; /* Safe, since we already filtered out empty string */
-    break;
+  return size;
+}
 
-    /* Powers of 1024 */
-  case 'e': case 'E':
-    scale *= 1024;
-    /* fallthru */
-  case 'p': case 'P':
-    scale *= 1024;
-    /* fallthru */
-  case 't': case 'T':
-    scale *= 1024;
-    /* fallthru */
-  case 'g': case 'G':
-    scale *= 1024;
-    /* fallthru */
-  case 'm': case 'M':
-    scale *= 1024;
-    /* fallthru */
-  case 'k': case 'K':
-    scale *= 1024;
-    /* fallthru */
-  case 'b': case 'B':
-    break;
+NBDKIT_DLL_PUBLIC int
+nbdkit_parse_probability (const char *what, const char *str,
+                          double *retp)
+{
+  double d, d2;
+  char c;
+  int n;
 
-    /* "sectors", ie. units of 512 bytes, even if that's not the real
-     * sector size */
-  case 's': case 'S':
-    scale = 512;
-    break;
-
-  default:
-    nbdkit_error ("could not parse size: unknown suffix '%s'", end);
-    return -1;
+  if (sscanf (str, "%lg%[:/]%lg%n", &d, &c, &d2, &n) == 3 &&
+      strcmp (&str[n], "") == 0) { /* N:M or N/M */
+    if (d == 0.0 && d2 == 0.0)     /* 0/0 is OK */
+      ;
+    else if (d2 == 0)              /* N/0 is bad */
+      goto bad_parse;
+    else
+      d /= d2;
   }
-
-  /* XXX Maybe we should support 'MiB' as a synonym for 'M'; and 'MB'
-   * for powers of 1000, for similarity to GNU tools. But for now,
-   * anything beyond 'M' is dropped.  */
-  if (end[1]) {
-    nbdkit_error ("could not parse size: unknown suffix '%s'", end);
-    return -1;
+  else if (sscanf (str, "%lg%n", &d, &n) == 1) {
+    if (strcmp (&str[n], "%") == 0) /* percentage */
+      d /= 100.0;
+    else if (strcmp (&str[n], "") == 0) /* probability */
+      ;
+    else
+      goto bad_parse;
   }
+  else
+    goto bad_parse;
 
-  if (INT64_MAX / scale < size) {
-    nbdkit_error ("overflow computing size (%s)", str);
-    return -1;
-  }
+  if (!isfinite (d))            /* reject NaN or inf */
+    goto bad_parse;
+  if (signbit (d))              /* reject negative numbers */
+    goto bad_parse;
 
-  return size * scale;
+  if (retp)
+    *retp = d;
+  return 0;
+
+ bad_parse:
+  nbdkit_error ("%s: could not parse '%s' as a probability", what, str);
+  return -1;
 }
 
 /* Parse a string as a boolean, or return -1 after reporting the error.
@@ -446,6 +423,53 @@ nbdkit_parse_bool (const char *str)
   return -1;
 }
 
+/* Parse a delay or sleep. */
+NBDKIT_DLL_PUBLIC int
+nbdkit_parse_delay (const char *what, const char *str,
+                    unsigned *rsec, unsigned *rnsec)
+{
+  double d;
+  int n;
+
+  if (sscanf (str, "%lg%n", &d, &n) == 1) {
+    if (strcmp (&str[n], "s") == 0 || strcmp (&str[n], "") == 0) {
+      /* Seconds. */
+    }
+    else if (strcmp (&str[n], "ms") == 0) {
+      /* Milliseconds. */
+      d /= 1000;
+    }
+    else if (strcmp (&str[n], "us") == 0 || strcmp (&str[n], "μs") == 0) {
+      /* Microseconds. */
+      d /= 1000000;
+    }
+    else if (strcmp (&str[n], "ns") == 0) {
+      /* Nanoseconds. */
+      d /= 1000000000;
+    }
+    else
+      goto bad_parse;
+  }
+  else {
+  bad_parse:
+    nbdkit_error ("%s: could not parse delay or sleep: \"%s\"",
+                  what, str);
+    return -1;
+  }
+
+  if (!isfinite (d))            /* reject NaN or inf */
+    goto bad_parse;
+  if (signbit (d))              /* reject negative numbers */
+    goto bad_parse;
+
+  if (rsec)
+    *rsec = d;
+  if (rnsec)
+    *rnsec = (d - *rsec) * 1000000000.;
+
+  return 0;
+}
+
 /* Return true if it is safe to read from stdin during configuration. */
 NBDKIT_DLL_PUBLIC int
 nbdkit_stdio_safe (void)
@@ -971,7 +995,7 @@ get_peercred_common (int64_t *pid, int64_t *uid, int64_t *gid)
 }
 
 NBDKIT_DLL_PUBLIC int64_t
-nbdkit_peer_pid ()
+nbdkit_peer_pid (void)
 {
   int64_t pid;
 
@@ -982,7 +1006,7 @@ nbdkit_peer_pid ()
 }
 
 NBDKIT_DLL_PUBLIC int64_t
-nbdkit_peer_uid ()
+nbdkit_peer_uid (void)
 {
   int64_t uid;
 
@@ -993,7 +1017,7 @@ nbdkit_peer_uid ()
 }
 
 NBDKIT_DLL_PUBLIC int64_t
-nbdkit_peer_gid ()
+nbdkit_peer_gid (void)
 {
   int64_t gid;
 
@@ -1003,6 +1027,84 @@ nbdkit_peer_gid ()
   return gid;
 }
 
+#ifdef SO_PEERSEC
+
+NBDKIT_DLL_PUBLIC char *
+nbdkit_peer_security_context (void)
+{
+  struct connection *conn = threadlocal_get_conn ();
+  int s;
+  char *label = NULL;
+  socklen_t optlen = 0;
+  int r;
+
+  if (!conn) {
+    nbdkit_error ("no connection in this thread");
+    return NULL;
+  }
+
+  s = conn->sockin;
+  if (s == -1) {
+    nbdkit_error ("socket not open");
+    return NULL;
+  }
+
+  /* Get the length of the label before allocating.  Note the ip(7)
+   * manual implies that the level should be IPPROTO_IP for AF_INET
+   * sockets.  However Linux always uses SOL_SOCKET.
+   */
+  errno = 0;
+  r = getsockopt (conn->sockin, SOL_SOCKET, SO_PEERSEC, label, &optlen);
+  if (r == 0) {
+    /* Zero-length label probably. */
+    label = calloc (1, 1);
+    if (label == NULL) {
+      nbdkit_error ("calloc: %m");
+      return NULL;
+    }
+    return label; /* caller frees */
+  }
+  else if (r == -1 && errno == ENOPROTOOPT) {
+    /* This is not really an error so don't call nbdkit_error. */
+    nbdkit_debug ("getsockopt: SO_PEERSEC: %m");
+    return NULL;
+  }
+  else if (r == -1 && errno != ERANGE) {
+    nbdkit_error ("getsockopt: SO_PEERSEC: %m");
+    return NULL;
+  }
+
+  /* It's not defined if Linux will NUL-terminate the returned string,
+   * or even if it will completely fill the buffer, so we play it safe
+   * here.
+   */
+  label = calloc (optlen+1, 1);
+  if (label == NULL) {
+    nbdkit_error ("calloc: %m");
+    return NULL;
+  }
+
+  /* Read the label. */
+  if (getsockopt (conn->sockin, SOL_SOCKET, SO_PEERSEC, label, &optlen) == -1) {
+    nbdkit_error ("getsockopt: SO_PEERSEC: %m");
+    free (label);
+    return NULL;
+  }
+
+  return label; /* caller frees */
+}
+
+#else /* !SO_PEERSEC */
+
+NBDKIT_DLL_PUBLIC char *
+nbdkit_peer_security_context (void)
+{
+  nbdkit_error ("SO_PEERSEC is not available on this platform");
+  return NULL;
+}
+
+#endif /* !SO_PEERSEC */
+
 /* Functions for manipulating intern'd strings. */
 
 static string_vector global_interns;
