@@ -4,7 +4,7 @@
 # shell as an impossible command which is ignored.  The line below is
 # run by the shell and ignored by OCaml.
 
-exec nbdkit cc "$0" CC=ocamlopt CFLAGS="-output-obj -runtime-variant _pic $OCAML_PLUGIN_LIBRARIES NBDKit.cmx -cclib -L../plugins/ocaml/.libs -cclib -lnbdkitocaml" "$@"
+exec nbdkit cc "$0" CC=ocamlopt CFLAGS="-output-obj -runtime-variant _pic $OCAML_STD_INCLUDES $OCAML_PLUGIN_LIBRARIES NBDKit.cmx -cclib -L../plugins/ocaml/.libs -cclib -lnbdkitocaml" "$@"
 *)
 
 open Printf
@@ -24,15 +24,15 @@ let open_connection _ = ()
 
 let get_size () = Bytes.length !disk |> Int64.of_int
 
-let pread () count offset _ =
-  let buf = Bytes.create count in
-  Bytes.blit !disk (Int64.to_int offset) buf 0 count;
-  Bytes.unsafe_to_string buf
+let pread () buf offset _ =
+  let len = NBDKit.buf_len buf in
+  let offset = Int64.to_int offset in
+  NBDKit.blit_bytes_to_buf !disk offset buf 0 len
 
 let pwrite () buf offset _ =
-  let len = String.length buf in
+  let len = NBDKit.buf_len buf in
   let offset = Int64.to_int offset in
-  String.blit buf 0 !disk offset len
+  NBDKit.blit_buf_to_bytes buf 0 !disk offset len
 
 let () =
   NBDKit.register_plugin
