@@ -45,6 +45,7 @@
 #include "cleanup.h"
 #include "web-server.h"
 
+#include "requires.h"
 #include "test.h"
 
 /* Check that the cookie and headers are sent in each request.  This
@@ -77,9 +78,7 @@ main (int argc, char *argv[])
   CLEANUP_FREE char *usp_param = NULL;
 
 #ifndef HAVE_CURLOPT_UNIX_SOCKET_PATH
-  fprintf (stderr, "%s: curl does not support CURLOPT_UNIX_SOCKET_PATH\n",
-           program_name);
-  exit (77);
+  skip_because ("curl does not support CURLOPT_UNIX_SOCKET_PATH");
 #endif
 
   sockpath = web_server ("disk", check_request, false);
@@ -137,6 +136,7 @@ main (int argc, char *argv[])
     exit (EXIT_FAILURE);
   }
 
+  free (data);
   guestfs_close (g);
   exit (EXIT_SUCCESS);
 }
