@@ -30,10 +30,6 @@
 # OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-# Unfortunately the output of this test depends on the SPARSE_PAGE
-# defined in common/allocators/sparse.c and would change (breaking the
-# test) if we ever changed that definition.
-
 source ./functions.sh
 set -e
 set -x
@@ -42,6 +38,7 @@ requires_run
 requires jq --version
 requires qemu-img --version
 requires qemu-img map --help
+error_if_sparse_page_not_32768
 
 # Because of macOS SIP misfeature the DYLD_* environment variable
 # added by libnbd/run is filtered out and the test won't work.  Skip
@@ -68,7 +65,7 @@ do_test ()
            truncate="$3"
     # We use jq to normalize the output and convert it to plain text.
     nbdkit nbd socket="$sock" \
-           --run 'qemu-img map -f raw --output=json $nbd' |
+           --run 'qemu-img map -f raw --output=json "$uri"' |
         jq -c '.[] | {start:.start, length:.length, data:.data, zero:.zero}' \
            > $out
     rm -f "$sock"
