@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # nbdkit
-# Copyright (C) 2019-2020 Red Hat Inc.
+# Copyright Red Hat
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -56,8 +56,8 @@ if [ ! -f "$pkidir/ca-cert.pem" ]; then
     exit 77
 fi
 
-sock1=`mktemp -u`
-sock2=`mktemp -u`
+sock1=$(mktemp -u /tmp/nbdkit-test-sock.XXXXXX)
+sock2=$(mktemp -u /tmp/nbdkit-test-sock.XXXXXX)
 pid1="test-nbd-tls.pid1"
 pid2="test-nbd-tls.pid2"
 
@@ -73,7 +73,8 @@ start_nbdkit -P "$pid2" -U "$sock2" --tls=off \
 
 # Run encrypted server
 start_nbdkit -P "$pid1" -U "$sock1" \
-    --tls=require --tls-certificates="$pkidir" example1
+    --tls=require --tls-certificates="$pkidir" -D nbdkit.tls.session=1 \
+    example1
 
 # Run unencrypted client
 qemu-img info --output=json -f raw "nbd+unix:///?socket=$sock2" > nbd-tls.out
