@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # nbdkit
-# Copyright (C) 2018-2020 Red Hat Inc.
+# Copyright Red Hat
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -34,17 +34,10 @@ source ./functions.sh
 set -e
 set -x
 
-if test ! -d "$SRCDIR"; then
-    echo "$0: could not locate python-export-list.py"
-    exit 1
-fi
-
-# Python has proven very difficult to valgrind, therefore it is disabled.
-if [ "$NBDKIT_VALGRIND" = "1" ]; then
-    echo "$0: skipping Python test under valgrind."
-    exit 77
-fi
+script=$abs_top_srcdir/tests/python-export-list.py
+test -f "$script"
 
+skip_if_valgrind "because Python code leaks memory"
 requires_nbdinfo
 requires_nbdsh_uri
 requires nbdsh -c 'print(h.set_full_info)'
@@ -57,7 +50,7 @@ files="$pid $sock $out"
 rm -f $files
 cleanup_fn rm -f $files
 
-start_nbdkit -P $pid -U $sock python $SRCDIR/python-export-list.py
+start_nbdkit -P $pid -U $sock python $script
 
 nbdinfo --list --json nbd+unix://\?socket=$sock > $out
 cat $out
