@@ -57,7 +57,7 @@ cleanup_fn rm -f $files
 echo 10M > rate-dynamic.txt
 
 start_t=$SECONDS
-nbdkit -U - \
+nbdkit \
        --filter=blocksize --filter=rate \
        pattern 25M \
        maxdata=65536 \
